@@ -1,7 +1,7 @@
 package Pcore::App::API::Local::sqlite;
 
 use Pcore -class, -result, -sql;
-use Pcore::Util::UUID qw[uuid_str];
+use Pcore::Util::UUID qw[uuid_v1mc_str];
 
 with qw[Pcore::App::API::Local];
 
@@ -68,7 +68,7 @@ SQL
 
 sub _db_add_roles ( $self, $dbh, $roles, $cb ) {
     $dbh->do(
-        [ q[INSERT OR IGNORE INTO "api_role"], VALUES [ map { { id => uuid_str, name => $_ } } $roles->@* ] ],
+        [ q[INSERT OR IGNORE INTO "api_role"], VALUES [ map { { id => uuid_v1mc_str, name => $_ } } $roles->@* ] ],
         sub ( $dbh, $res, $data ) {
             $cb->($res);
 
@@ -80,7 +80,7 @@ sub _db_add_roles ( $self, $dbh, $roles, $cb ) {
 }
 
 sub _db_create_user ( $self, $dbh, $user_name, $hash, $enabled, $cb ) {
-    my $user_id = uuid_str;
+    my $user_id = uuid_v1mc_str;
 
     $dbh->do(
         'INSERT OR IGNORE INTO "api_user" ("id", "name", "hash", "enabled") VALUES (?, ?, ?, ?)',
