@@ -1,11 +1,9 @@
 package Pcore::Dist::Build::Clean;
 
-use Pcore qw[-class -const];
+use Pcore -class, -const;
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
 
-no Pcore;
-
 const our $DIR => [
 
     # general build
