@@ -30,13 +30,9 @@ sub CLI ($self) {
 }
 
 sub CLI_RUN ( $self, $opt, $arg, $rest ) {
-    $self->new->run($opt);
+    my $dist = $self->get_dist;
 
-    return;
-}
-
-sub run ( $self, $args ) {
-    exit 3 if !$self->dist->build->test( $args->%*, smoke => 1 );
+    exit 3 if !$dist->build->test( $opt->%*, smoke => 1 );
 
     return;
 }
